@@ -81,8 +81,8 @@ CreateTcm <- function(doc_vec, skipgram_window = Inf, ngram_window = c(1, 1),
   }
   
   if (remove_punctuation) {
-    doc_vec <- stringr::str_replace_all(doc_vec, "[^a-zA-Z0-9]", " ")
-    stopword_vec <- stringr::str_replace_all(stopword_vec, "[^a-zA-Z0-9]", " ")
+    doc_vec <- stringr::str_replace_all(doc_vec, "[^[:alnum:]]", " ")
+    stopword_vec <- stringr::str_replace_all(stopword_vec, "[^[:alnum:]]", " ")
     stopword_vec <- unique(unlist(stringr::str_split(string = stopword_vec, 
                                                      pattern = "\\s+")))
   }
@@ -162,6 +162,8 @@ CreateTcm <- function(doc_vec, skipgram_window = Inf, ngram_window = c(1, 1),
     
     tcm <- text2vec::create_tcm(it, vectorizer)
     
+    tcm <- methods::as(tcm, "dgCMatrix", strict = TRUE)
+    
     return(tcm)
   }
 }
\ No newline at end of file
